/*  Copyright (c) MIPoPS. All Rights Reserved.
 *
 *  Use of this source code is governed by a Unlicense license that can
 *  be found in the LICENSE file in the root of the source tree.
 */

//---------------------------------------------------------------------------
#include "CLI/CommandLine_Parser.h"
#include "CLI/CLI_Help.h"
#include "Common/Core.h"
#if defined(UNICODE) && defined(_WIN32)
    #include <windows.h>
#endif
//---------------------------------------------------------------------------

//***************************************************************************
// Command line parser
//***************************************************************************

return_value Parse(Core &C, int argc, const char* argv_ansi[], MediaInfoNameSpace::Char* argv[])
{
    if (argc < 2)
        return Usage(argv_ansi[0]);

    bool IsOk = false;

    for (int i = 1; i < argc; i++)
    {
             if (strcmp(argv_ansi[i], "--help") == 0 || strcmp(argv_ansi[i], "-h") == 0)
        {
            if (auto Value = Help(argv_ansi[0]))
                return Value;
            IsOk = true;
        }
        else if (strcmp(argv_ansi[i], "--version") == 0)
        {
            if (auto Value = NameVersion())
                return Value;
            IsOk = true;
        }
        else if (strcmp(argv_ansi[i], "--xml") == 0)
        {
            C.Xml = true;
        }
        else
            C.Inputs.push_back(argv[i]);
    }

    if (!IsOk && C.Inputs.empty())
        return ReturnValue_ERROR;

    return ReturnValue_OK;
}

return_value Parse(Core &C, int argc, const char* argv_ansi[])
{
    //Get command line args in main()
#ifdef UNICODE
#ifdef _WIN32
    MediaInfoNameSpace::Char** argv = CommandLineToArgvW(GetCommandLineW(), &argc);
#else //WIN32
    std::vector<MediaInfoNameSpace::String> argv; //TODO
    for (int Pos = 0; Pos < argc; Pos++)
    {
        ZenLib::Ztring A;
        A.From_Local(argv_ansi[Pos]);
        argv.push_back(A);
    }
#endif //WIN32
#else //UNICODE
    MediaInfoNameSpace::Char** argv = argv_ansi;
#endif //UNICODE

    return_value ReturnValue = Parse(C, argc, argv_ansi, argv);

    // Manage memory
#ifdef UNICODE
#ifdef _WIN32
    LocalFree(argv);
#else //WIN32
    //TODO
#endif //WIN32
#endif //UNICODE

    return ReturnValue;
}
